@@ -603,20 +603,6 @@ class SklLearner(Learner, metaclass=WrapperMeta):
             return self.__returns__(clf.fit(X, Y))
         return self.__returns__(clf.fit(X, Y, sample_weight=W.reshape(-1)))
 
-    @property
-    def supports_weights(self):
-        """Indicates whether this learner supports weighted instances.
-        """
-        warnings.warn('SklLearner.supports_weights property is deprecated. All '
-                      'subclasses should redefine the supports_weights attribute. '
-                      'The property will be removed in 3.39.',
-                      OrangeDeprecationWarning)
-        varnames = self.__wraps__.fit.__code__.co_varnames
-        # scikit-learn often uses decorators on fit()
-        if hasattr(self.__wraps__.fit, "__wrapped__"):
-            varnames = varnames + self.__wraps__.fit.__wrapped__.__code__.co_varnames
-        return 'sample_weight' in varnames
-
     def __getattr__(self, item):
         try:
             return self.params[item]
