@@ -1,5 +1,5 @@
 # Pull members from modules to Orange.classification namespace
-# pylint: disable=wildcard-import
+# pylint: disable=wildcard-import,broad-except
 
 from .base_classification import (ModelClassification as Model,
                                   LearnerClassification as Learner,
@@ -23,7 +23,7 @@ from .calibration import *
 from .scoringsheet import *
 try:
     from .catgb import *
-except ModuleNotFoundError:
+except Exception:
     pass
 from .gb import *
 try:
