@@ -430,7 +430,7 @@ class TestDomainInit(unittest.TestCase):
         domain = Domain([DiscreteVariable("a", values="01"),
                          DiscreteVariable("b", values="01")],
                         DiscreteVariable("y", values="01"))
-        table = Table.from_list(domain, [[0, 1], [1, np.NaN]], [0, 1])
+        table = Table.from_list(domain, [[0, 1], [1, np.nan]], [0, 1])
         pre1 = Continuize()(Impute()(table))
         pre2 = table.transform(pre1.domain)
         np.testing.assert_almost_equal(pre1.X, pre2.X)
