@@ -53,7 +53,6 @@ from pandas import CategoricalDtype
 from pandas.api import types as pdtypes
 
 from orangecanvas.utils import assocf
-from orangecanvas.utils.qobjref import qobjref_weak
 from orangewidget.utils import enum_as_int
 
 import Orange.data
@@ -627,12 +626,15 @@ class OWCSVFileImport(OWUrlDropBase):
         data = widget.Output(
             name="Data",
             type=Orange.data.Table,
-            doc="Loaded data set.")
+            doc="Loaded data set.",
+            dynamic=False,
+        )
         data_frame = widget.Output(
             name="Data Frame",
             type=pd.DataFrame,
             doc="",
-            auto_summary=False
+            auto_summary=False,
+            dynamic=False,
         )
 
     class Error(widget.OWWidget.Error):
@@ -975,8 +977,8 @@ class OWCSVFileImport(OWUrlDropBase):
         path = item.path()
         options = item.options()
 
-        def onfinished(dlg: CSVImportDialog):
-            if dlg.result() != QDialog.Accepted:
+        def onfinished(result: int):
+            if result != QDialog.Accepted:
                 return
             newoptions = dlg.options()
             item.setData(newoptions, ImportItem.OptionsRole)
@@ -985,11 +987,12 @@ class OWCSVFileImport(OWUrlDropBase):
             if newoptions != options:
                 self._invalidate()
 
-        self._activate_import_dialog_for_item(item, finished=onfinished)
+        dlg = self._activate_import_dialog_for_item(item)
+        dlg.finished.connect(onfinished)
 
     def _activate_import_dialog_for_item(
-            self, item: ImportItem, finished: Callable[[CSVImportDialog], None]
-    ):
+            self, item: ImportItem,
+    ) -> CSVImportDialog:
         dlg = CSVImportDialog(
             self, windowTitle="Import Options", sizeGripEnabled=True,
         )
@@ -1007,15 +1010,12 @@ class OWCSVFileImport(OWUrlDropBase):
         if isinstance(options, Options):
             dlg.setOptions(options)
 
-        dialog_ref = qobjref_weak(dlg)
-
         def onfinished():
-            dlg = dialog_ref()
             settings.setValue("size", dlg.size())
-            finished(dlg)
 
         dlg.finished.connect(onfinished)
         dlg.show()
+        return dlg
 
     def set_selected_file(self, filename, options=None):
         """
@@ -1354,12 +1354,13 @@ class OWCSVFileImport(OWUrlDropBase):
         item.setPath(path)
         item.setOptions(options)
 
-        def finished(dlg: CSVImportDialog):
-            if dlg.result() != QDialog.Accepted:
+        def finished(result: int):
+            if result != QDialog.Accepted:
                 return
             self.set_selected_file(path, dlg.options())
 
-        self._activate_import_dialog_for_item(item, finished)
+        dlg = self._activate_import_dialog_for_item(item)
+        dlg.finished.connect(finished)
 
     @classmethod
     def migrate_settings(cls, settings, version):
@@ -1608,8 +1609,8 @@ def load_csv(path, opts, progress_callback=None, compatibility_mode=False):
             for date_col in parse_dates:
                 if df.dtypes[date_col] == "object":
                     df[df.columns[date_col]] = pd.to_datetime(
-                        df.iloc[:, date_col], errors="coerce"
-                    )
+                        df.iloc[:, date_col], errors="coerce", utc=True,
+                    ).dt.tz_localize(None)
         if prefix:
             df.columns = [f"{prefix}{column}" for column in df.columns]
 
@@ -1832,7 +1833,9 @@ def pandas_to_table(df):
             orangecol = np.array(codes, dtype=float)
             orangecol[codes < 0] = np.nan
         elif pdtypes.is_datetime64_any_dtype(series):
-            # Check that this converts tz local to UTC
+            # Convert (possible) tz local to UTC
+            if series.dt.tz is not None:
+                series = series.dt.tz_convert("UTC").dt.tz_localize(None)
             series = series.astype(np.dtype("M8[ns]"))
             coldata = series.values  # type: np.ndarray
             assert coldata.dtype == "M8[ns]"
