@@ -2,6 +2,7 @@
 # pylint: disable=all
 import pickle
 import unittest
+from datetime import datetime, timezone
 from functools import partial
 from itertools import product, chain
 from unittest import TestCase
@@ -36,7 +37,7 @@ from Orange.widgets.data.oweditdomain import (
     RealVector, TimeVector, StringVector, make_dict_mapper,
     LookupMappingTransform, as_float_or_nan, column_str_repr,
     GroupItemsDialog, VariableListModel, StrpTime, RestoreOriginal, BaseEditor,
-    RestoreWarningRole
+    RestoreWarningRole, TimeUnit
 )
 from Orange.widgets.data.owcolor import OWColor, ColorRole
 from Orange.widgets.tests.base import WidgetTest, GuiTest
@@ -100,6 +101,13 @@ class TestReport(TestCase):
             self.assertIn("→ (", t)
 
 
+def enter_text(widget: QLineEdit, text: str):
+    widget.selectAll()
+    QTest.keyClick(widget, Qt.Key.Key_Delete)
+    QTest.keyClicks(widget, text)
+    QTest.keyClick(widget, Qt.Key.Key_Return)
+
+
 class TestOWEditDomain(WidgetTest):
     def setUp(self):
         self.widget = self.create_widget(OWEditDomain)
@@ -257,13 +265,6 @@ class TestOWEditDomain(WidgetTest):
         self.widget.domain_view.setCurrentIndex(idx)
         editor = self.widget.findChild(ContinuousVariableEditor)
 
-        def enter_text(widget, text):
-            # type: (QLineEdit, str) -> None
-            widget.selectAll()
-            QTest.keyClick(widget, Qt.Key_Delete)
-            QTest.keyClicks(widget, text)
-            QTest.keyClick(widget, Qt.Key_Return)
-
         enter_text(editor.name_edit, "iris")
         self.widget.commit()
         self.assertTrue(self.widget.Error.duplicate_var_name.is_shown())
@@ -342,6 +343,35 @@ class TestOWEditDomain(WidgetTest):
         output = self.get_output(self.widget.Outputs.data)
         self.assertEqual(str(table[0, 4]), str(output[0, 4]))
 
+    def test_custom_format(self):
+        time_variable = StringVariable("Date")
+        data = [
+            ["2024-001"],
+            ["2024-032"],
+            ["2024-150"],
+            ["2024-365"]
+        ]
+        table = Table.from_list(Domain([], metas=[time_variable]), data)
+        self.send_signal(self.widget.Inputs.data, table)
+        index = self.widget.variables_view.model().index
+        self.widget.variables_view.setCurrentIndex(index(0))
+
+        editor = self.widget.findChild(VariableEditor)
+        tc = editor.layout().currentWidget().findChild(QComboBox,
+                                                       name="type-combo")
+        # time variable editor
+        simulate.combobox_activate_item(tc, Time, Qt.ItemDataRole.UserRole)
+        le = editor.layout().currentWidget().findChild(QLineEdit, name="custom-format-line-edit")
+        enter_text(le, "%Y-%j")
+
+        self.widget.commit()
+        output = self.get_output(self.widget.Outputs.data)
+        self.assertEqual(table.metas[0, 0], "2024-001")
+        self.assertEqual(output.metas[0, 0],
+                         datetime.strptime("2024-001",
+                                           "%Y-%j").replace(
+                             tzinfo=timezone.utc).timestamp())
+
     def test_restore(self):
         iris = self.iris
         viris = (
@@ -621,8 +651,8 @@ class TestOWEditDomain(WidgetTest):
             {('Real', ('sepal length', (1, 'f'), ())):
                  [('AsString', ())],
              ('Real', ('sepal width', (1, 'f'), ())):
-                 [('AsTime', ()),
-                  ('StrpTime', ('Detect automatically', None, 1, 1))],
+                 [('AsTime', (('StrpTime',
+                               ('Detect automatically', None, 1, 1)),))],
              ('Real', ('petal width', (1, 'f'), ())):
                  [('Annotate', ((('a', 'b'),),))]}
         )
@@ -677,8 +707,43 @@ class TestOWEditDomain(WidgetTest):
                     [('AsString', ())]}
         )
 
+    def test_migrate_settings_4_to_5(self):
+        settings = {
+            '__version__': 4,
+            '_domain_change_hints': {
+                ('String', (), False):
+                    [('AsTime', ()), ('StrpTime', ('2021', ('%Y',), 1, 0))],
+            },
+            '_merge_dialog_settings': {},
+            'controlAreaVisible': True}
+        widget = self.create_widget(OWEditDomain, stored_settings=settings)
+        self.assertEqual(
+            widget._domain_change_hints,
+            {('String', (), False):
+                [('AsTime', (('StrpTime', ('2021', ('%Y',), 1, 0)),))],
+            },
+        )
+
+def transform_eq(first, second) -> bool:
+    """
+    Specialize equality for transforms to simplify tests:
+      * AsTime(None) == AsTime(DefaultStrpTime)
+      * AsTime(None) == AsTime(DefaultTimeUnit)
+    """
+    if isinstance(first, AsTime) and isinstance(second, AsTime):
+        p1, p2 = first.param, second.param
+        if (p1 is None) ^ (p2 is None):
+            param = p1 or p2
+            return param == DefaultStrpTime or param == DefaultTimeUnit
+    return first == second
+
 
 class TestEditors(GuiTest):
+
+    def assertTransformsEqual(self, first, second):
+        if not all(transform_eq(t1, t1) for t1, t2 in zip(first, second)):
+            self.assertSequenceEqual(first, second)
+
     def test_variable_editor(self):
         w = VariableEditor()
         self.assertEqual(w.get_data(), (None, []))
@@ -929,7 +994,7 @@ class TestEditors(GuiTest):
     ]
     ReinterpretTransforms = {
         Categorical: [AsCategorical], Real: [AsContinuous],
-        Time: [AsTime, partial(StrpTime, 'Detect automatically', None, 1, 1)],
+        Time: [AsTime],
         String: [AsString]
     }
 
@@ -949,7 +1014,7 @@ class TestEditors(GuiTest):
             if not tr_[0]:
                 self.assertEqual(tr, self.ReinterpretTransforms[type(*v)])
             else:
-                self.assertListEqual(*tr_, [t() for t in tr])
+                self.assertTransformsEqual(*tr_, [t() for t in tr])
 
     def test_reinterpret_editor_simulate(self):
         w = ReinterpretVariableEditor()
@@ -959,7 +1024,7 @@ class TestEditors(GuiTest):
             var, tr = var[0], tr[0]
             type_ = tc.currentData()
             if type_ is not type(var):
-                self.assertEqual(
+                self.assertTransformsEqual(
                     tr, [t() for t in self.ReinterpretTransforms[type_]] + [Rename("Z")]
                 )
             else:
@@ -1166,6 +1231,21 @@ class TestEditors(GuiTest):
         w._set_unlink(False)
         self.assertFalse(cbox.isChecked())
 
+    def test_reinterpret_time_format_restore(self):
+        w = ReinterpretVariableEditor()
+        transforms = [AsTime(StrpTime(None, ("%Y",), 1, 0)),
+                      Rename("Time"),]
+        w.set_data([self.DataVectors[3]], [transforms])
+        _, [t] = w.get_data()
+        self.assertEqual(t, transforms)
+
+    def test_reinterpret_time_unit_restore(self):
+        w = ReinterpretVariableEditor()
+        transforms = [AsTime(TimeUnit("Year", "Y0")),
+                      Rename("Time"), ]
+        w.set_data([self.DataVectors[1]], [transforms])
+        _, [t] = w.get_data()
+        self.assertEqual(t, transforms)
 
 class TestModels(GuiTest):
     def test_variable_model(self):
@@ -1322,6 +1402,9 @@ class TestTransforms(TestCase):
         self.assertIs(first.variable, second.variable)
         assert_array_equal(first.lookup_table, second.lookup_table)
 
+DefaultStrpTime = StrpTime("Detect automatically", None, 1, 1)
+DefaultTimeUnit = TimeUnit("Default", "s")
+
 
 class TestReinterpretTransforms(TestCase):
     @classmethod
@@ -1369,7 +1452,7 @@ class TestReinterpretTransforms(TestCase):
                 ["a", "2", "0.25", "00:03:00"],
                 ["b", "1", "1.25", "00:06:00"],
                 ["c", "0", "0.2", "00:12:00"],
-                ["b", "0", "0.0", "00:00:00"],
+                ["b", "0", "0", "00:00:00"],
             ], dtype=object)
         )
 
@@ -1398,8 +1481,8 @@ class TestReinterpretTransforms(TestCase):
         self.assertEqual(tdomain["C"].values, ("0.0", "0.2", "0.25", "1.25"))
         self.assertEqual(
             tdomain["D"].values,
-            ("1970-01-01 00:00:00", "1970-01-01 00:03:00",
-             "1970-01-01 00:06:00", "1970-01-01 00:12:00")
+            ("00:00:00", "00:03:00",
+             "00:06:00", "00:12:00")
         )
 
     def test_as_continuous(self):
@@ -1450,13 +1533,12 @@ class TestReinterpretTransforms(TestCase):
         metas = [t for t in times] + [list(range(len(x))) for x in times]
         table = Table(domain, np.empty((len(times[0]), 0)), metas=np.array(metas).transpose())
 
-        tr = AsTime()
+        # tr = AsTime()
         dtr = []
         for v, f in zip(domain.metas, chain(formats, formats)):
             strp = StrpTime(f, *TimeVariable.ADDITIONAL_FORMATS[f])
-            vtr = apply_transform_var(
-                apply_reinterpret(v, tr, table_column_data(table, v)), [strp]
-            )
+            tr = AsTime(strp)
+            vtr = apply_reinterpret(v, tr, table_column_data(table, v))
             dtr.append(vtr)
 
         ttable = table.transform(Domain([], metas=dtr))
@@ -1471,14 +1553,11 @@ class TestReinterpretTransforms(TestCase):
         tvars = []
         for v in domain.metas:
             for i, tr in enumerate(
-                [AsContinuous(), AsCategorical(), AsTime(), AsString()]
+                [AsContinuous(), AsCategorical(), AsTime(DefaultStrpTime), AsString()]
             ):
                 vtr = apply_reinterpret(v, tr, table_column_data(table, v)).renamed(
                     f"{v.name}_{i}"
                 )
-                if isinstance(tr, AsTime):
-                    strp = StrpTime("Detect automatically", None, 1, 1)
-                    vtr = apply_transform_var(vtr, [strp])
                 tvars.append(vtr)
         tdomain = Domain([], metas=tvars)
         ttable = table.transform(tdomain)
@@ -1525,13 +1604,10 @@ class TestReinterpretTransforms(TestCase):
 
     def test_to_time_variable(self):
         table = self.data
-        tr = AsTime()
+        tr = AsTime(None)
         dtr = []
         for v in table.domain:
-            strp = StrpTime("Detect automatically", None, 1, 1)
-            vtr = apply_transform_var(
-                apply_reinterpret(v, tr, table_column_data(table, v)), [strp]
-            )
+            vtr = apply_reinterpret(v, tr, table_column_data(table, v))
             dtr.append(vtr)
         ttable = table.transform(Domain([], metas=dtr))
         for var in ttable.domain:
