@@ -284,25 +284,21 @@ class TestOWPivot(WidgetTest):
         self.assertEqual(model.data(model.index(5, 4)), "reversable defect")
 
     def test_only_metas_table(self):
-        self.send_signal(self.widget.Inputs.data, self.zoo[:, 17:])
-        self.assertTrue(self.widget.Warning.no_variables.is_shown())
-
         data = self.zoo.transform(Domain([], metas=self.zoo.domain.attributes))
         self.send_signal(self.widget.Inputs.data, data)
         self.assertFalse(self.widget.Warning.no_variables.is_shown())
 
     def test_empty_table(self):
-        data = self.heart_disease[:, :0]
+        zoo_domain = self.zoo.domain
+        data = self.zoo.transform(Domain([], metas=zoo_domain.metas))
         self.send_signal(self.widget.Inputs.data, data)
         self.assertTrue(self.widget.Warning.no_variables.is_shown())
         self.send_signal(self.widget.Inputs.data, None)
         self.assertFalse(self.widget.Warning.no_variables.is_shown())
 
-        data = self.heart_disease
-        self.send_signal(self.widget.Inputs.data, data)
+        heart = self.heart_disease
+        self.send_signal(self.widget.Inputs.data, heart)
 
-        zoo_domain = self.zoo.domain
-        data = self.zoo.transform(Domain([], metas=zoo_domain.metas))
         self.send_signal(self.widget.Inputs.data, data)
 
         domain = Domain([], zoo_domain.class_vars, metas=zoo_domain.metas)
