@@ -18,7 +18,7 @@ from Orange.data import Table
 from Orange.evaluation import CrossValidation, TestOnTrainingData, Results
 from Orange.evaluation.scoring import Score, AUC, R2
 from Orange.modelling import Fitter
-from Orange.util import dummy_callback
+from Orange.util import dummy_callback, wrap_callback
 from Orange.widgets import gui
 from Orange.widgets.settings import Setting
 from Orange.widgets.utils import userinput
@@ -42,12 +42,19 @@ FitterResults = tuple[list[ScoreType], str, str]
 def _validate(
         data: Table,
         learner: Learner,
-        scorer: type[Score]
+        scorer: type[Score],
+        progress_callback: Callable
 ) -> tuple[float, float]:
     res: Results = TestOnTrainingData()(data, [learner],
-                                        suppresses_exceptions=False)
+                                        suppresses_exceptions=False,
+                                        callback=wrap_callback(
+                                            progress_callback, 0, 1/(1+N_FOLD))
+                                        )
     res_cv: Results = CrossValidation(k=N_FOLD)(data, [learner],
-                                                suppresses_exceptions=False)
+                                                suppresses_exceptions=False,
+                                                callback=wrap_callback(
+                                                    progress_callback, 1/(1+N_FOLD), 1.)
+                                                )
     # pylint: disable=unsubscriptable-object
     return scorer(res)[0], scorer(res_cv)[0]
 
@@ -65,10 +72,10 @@ def _search(
     scorer = AUC if data.domain.has_discrete_class else R2
     name = fitted_parameter_props.name
     for i, value in enumerate(steps):
-        progress_callback(i / len(steps))
         params = initial_parameters.copy()
         params[name] = value
-        result = _validate(data, type(learner)(**params), scorer)
+        result = _validate(data, type(learner)(**params), scorer,
+                           wrap_callback(progress_callback, i / len(steps), (i+1) / len(steps)))
         scores.append((value, result))
     return scores, scorer.name, fitted_parameter_props.label
 
