@@ -13,6 +13,8 @@ import numpy as np
 from AnyQt.QtCore import QItemSelectionModel, QItemSelection, Qt, QRect
 from AnyQt.QtWidgets import QToolTip
 
+from orangewidget.settings import Context
+
 from Orange.base import Model
 from Orange.classification import LogisticRegressionLearner, NaiveBayesLearner
 from Orange.classification.majority import ConstantModel, MajorityLearner
@@ -702,6 +704,11 @@ class TestOWPredictions(WidgetTest):
         self.assertFalse(self.widget.Warning.missing_targets.is_shown())
         self.assertFalse(self.widget.Error.scorer_failed.is_shown())
 
+        self.send_signal(self.widget.Inputs.predictors, model)
+        self.assertTrue(self.widget.Warning.missing_targets.is_shown())
+        self.widget.controls.show_scores.setChecked(False)
+        self.assertFalse(self.widget.Warning.missing_targets.is_shown())
+
     def test_missing_target_reg(self):
         mask = np.zeros(len(self.housing), dtype=bool)
         mask[::2] = True
@@ -1283,6 +1290,53 @@ class TestOWPredictions(WidgetTest):
         self.widget.migrate_settings(settings, 1)
         self.assertTrue(settings["score_table"]["show_score_hints"]["Sensitivity"])
 
+    def test_migrate_context_2_3(self):
+        settings = {
+            'controlAreaVisible': True, 'selection': [],
+            'show_scores': True,
+            'score_table': {
+                'show_score_hints': {
+                    'Model_': True, 'Train_': False, 'Test_': False,
+                    'CA': True, 'PrecisionRecallFSupport': True,
+                    'TargetScore': True, 'Precision': True,
+                    'Recall': True, 'F1': True, 'AUC': True,
+                    'LogLoss': False, 'Specificity': False,
+                    'MatthewsCorrCoefficient': True, 'MSE': True,
+                    'RMSE': True, 'MAE': True, 'MAPE': True, 'R2': True,
+                    'CVRMSE': False, 'ClusteringScore': True,
+                    'Silhouette': True, 'AdjustedMutualInfoScore': True}},
+            'context_settings': [
+                Context(
+                    classes=('Iris-setosa',
+                             'Iris-versicolor',
+                             'Iris-virginica'),
+                    values={'show_probability_errors': True,
+                            'show_reg_errors': 1,
+                            'shown_probs': 1,
+                            'score_table': {},
+                            'target_class': '(Average over classes)',
+                            '__version__': 2})],
+            '__version__': 2,
+        }
+
+        widget = self.create_widget(OWPredictions, stored_settings=settings)
+        self.send_signal(widget.Inputs.data, self.iris)
+        self.assertEqual(widget.target_class, "")
+
+        settings["context_settings"][0].values["target_class"] = "Iris-versicolor"
+        settings["__version__"] = 2
+        widget = self.create_widget(OWPredictions, stored_settings=settings)
+        self.send_signal(widget.Inputs.data, self.iris)
+        self.assertEqual(widget.target_class, "Iris-versicolor")
+
+        # Test fallback for older workflows opened in wrong language
+        settings["context_settings"][0].values["target_class"] = "Povprečje"
+        settings["__version__"] = 2
+        widget = self.create_widget(OWPredictions, stored_settings=settings)
+        self.send_signal(widget.Inputs.data, self.iris)
+        self.assertEqual(widget.target_class, "")
+
+
     def test_output_error_reg(self):
         data = self.housing
         lin_reg = LinearRegressionLearner()
@@ -1304,7 +1358,7 @@ class TestOWPredictions(WidgetTest):
         log_reg = LogisticRegressionLearner()
         self.send_signal(self.widget.Inputs.predictors, log_reg(data), 0)
         self.send_signal(self.widget.Inputs.predictors,
-                         LogisticRegressionLearner(penalty="l1")(data), 1)
+                         LogisticRegressionLearner(penalty="l1", max_iter=1000)(data), 1)
         with data.unlocked(data.Y):
             data.Y[1] = np.nan
         self.send_signal(self.widget.Inputs.data, data)
@@ -1316,7 +1370,7 @@ class TestOWPredictions(WidgetTest):
         names = [f"{log_reg.name}{x}" for x in names]
         self.assertEqual(names, [m.name for m in pred.domain.metas])
         self.assertAlmostEqual(pred.metas[0, 4], 0.018, 3)
-        self.assertAlmostEqual(pred.metas[0, 9], 0.113, 3)
+        self.assertAlmostEqual(pred.metas[0, 9], 0.008, 3)
         self.assertTrue(np.isnan(pred.metas[1, 4]))
         self.assertTrue(np.isnan(pred.metas[1, 9]))
 
