@@ -2,8 +2,10 @@
 # pylint: disable=protected-access
 import unittest
 from unittest.mock import Mock, patch
+from packaging.version import parse as parse_version
 
 import numpy as np
+from sklearn import __version__ as sklearn_version
 from AnyQt.QtCore import Qt
 from AnyQt.QtTest import QTest
 from AnyQt.QtWidgets import QApplication
@@ -367,13 +369,17 @@ class TestOWTestAndScore(WidgetTest):
             list(zip(*self.scores_table_values + [list("yyyn")]))
         )
 
-        self.assertTupleEqual(
-            self._test_scores(
-                table, table[:3], ConstantLearner(),
-                OWTestAndScore.TestOnTest, None
-            ),
-            (None, 1, 1, 1, 1)
+        scores = self._test_scores(
+            table, table[:3], ConstantLearner(),
+            OWTestAndScore.TestOnTest, None
         )
+        self.assertTupleEqual(scores[1:], (1, 1, 1, 1))
+
+        # Sklearn, we love you.
+        if parse_version(sklearn_version) < parse_version("1.6dev"):
+            self.assertIsNone(scores[0])
+        else:
+            self.assertTrue(np.isnan(scores[0]))
 
     def test_scores_log_reg_overfitted(self):
         table = Table.from_list(
