@@ -76,6 +76,7 @@ class TestOWtSNE(WidgetTest, ProjectionWidgetTestMixin, WidgetOutputsTestMixin):
         )
 
     def setUp(self):
+        super().setUp()
         # For almost all the tests, we won't need to verify t-SNE validity and
         # the tests will run much faster if we dummy them out
         self.tsne = patch("Orange.projection.manifold.TSNE", new=DummyTSNE)
@@ -102,6 +103,7 @@ class TestOWtSNE(WidgetTest, ProjectionWidgetTestMixin, WidgetOutputsTestMixin):
         except RuntimeError as e:
             if str(e) != "stop called on unstarted patcher":
                 raise e
+        super().tearDown()
 
     def restore_mocked_functions(self):
         self.tsne.stop()
@@ -895,6 +897,29 @@ class TestOWtSNE(WidgetTest, ProjectionWidgetTestMixin, WidgetOutputsTestMixin):
         w.controls.use_pca_preprocessing.setChecked(False)
         self.widget.run_button.click(), self.wait_until_finished()
 
+    def test_output_compute_value(self):
+        self.send_signal(self.widget.Inputs.data, self.data)
+        self.wait_until_finished()
+
+        data = self.get_output(self.widget.Outputs.annotated_data)
+        self.assertIsNotNone(data.domain.metas[0].compute_value)
+        self.assertIsNotNone(data.domain.metas[1].compute_value)
+
+        transformed = self.data.transform(data.domain)
+        self.assert_table_equal(transformed[:, ["t-SNE-x", "t-SNE-y"]],
+                                data[:, ["t-SNE-x", "t-SNE-y"]])
+
+    def test_output_repeating_names(self):
+        data = self.data.transform(Domain(self.data.domain.attributes
+                                          + (ContinuousVariable("t-SNE-x"),)))
+        self.send_signal(self.widget.Inputs.data, data)
+        self.wait_until_finished()
+
+        out = self.get_output(self.widget.Outputs.annotated_data)
+        meta_names = {a.name for a in out.domain.metas}
+        self.assertIn("t-SNE-x (1)", meta_names)
+        self.assertIn("t-SNE-y (1)", meta_names)
+
 
 class TestTSNERunner(unittest.TestCase):
     @classmethod
