@@ -135,7 +135,7 @@ class SortProxyModel(QSortFilterProxyModel):
         role = self.sortRole()
         l_score = left.data(role)
         r_score = right.data(role)
-        return r_score is not None and (l_score is None or l_score < r_score)
+        return r_score is not None and (l_score is None or bool(l_score < r_score))
 
 
 class OWBoxPlot(widget.OWWidget):
@@ -675,7 +675,8 @@ class OWBoxPlot(widget.OWWidget):
                 label.show()
 
         r = QRectF(self.scene_min_x, -30 - len(self.stats) * heights,
-                   self.scene_width, len(self.stats) * heights + 90)
+                   self.scene_width, len(self.stats) * heights + 90 +
+                   self._axis_font.pixelSize() * 4)
         self.box_scene.setSceneRect(r)
 
         self._compute_tests_cont()
@@ -683,6 +684,15 @@ class OWBoxPlot(widget.OWWidget):
 
     def _display_changed_disc(self):
         self.clear_scene()
+
+        if self.group_var and self.conts is None or \
+                not self.group_var and self.dist is None:  # readability counts
+            # This happens if the attribute or group attribute don't have any
+            # values. See the condition in compute_box_data. This tests can't
+            # be moved to input data handler because it's user-choice specific.
+            self.stat_test = ""
+            return
+
         self.attr_labels = [QGraphicsSimpleTextItem(lab)
                             for lab in self.label_txts_all]
 
@@ -733,7 +743,8 @@ class OWBoxPlot(widget.OWWidget):
 
         self.box_scene.setSceneRect(-self.label_width - 5,
                                     -30 - len(self.boxes) * 40,
-                                    self.scene_width, len(self.boxes * 40) + 90)
+                                    self.scene_width, len(self.boxes * 40) +
+                                    90 + self._axis_font.pixelSize() * 4)
         self._compute_tests_disc()
 
     def __draw_group_labels(self, y, row):
@@ -989,9 +1000,11 @@ class OWBoxPlot(widget.OWWidget):
             step = steps = 10
         else:
             if self.group_var:
+                assert self.conts is not None, "the callee must ensure this!"
                 max_box = max(float(np.sum(dist))
                               for dist in self.conts.array_with_unknowns)
             else:
+                assert self.dist is not None, "the callee must ensure this!"
                 max_box = float(np.sum(self.dist.array_with_unknowns))
             if max_box == 0:
                 self.scale_x = 1
@@ -1180,7 +1193,7 @@ class OWBoxPlot(widget.OWWidget):
         conditions = self._gather_conditions()
         if conditions:
             selected = Values(conditions, conjunction=False)(self.dataset)
-            selection = np.in1d(
+            selection = np.isin(
                 self.dataset.ids, selected.ids, assume_unique=True).nonzero()[0]
         else:
             selected, selection = None, []
