@@ -583,7 +583,7 @@ class OWHeatMap(widget.OWWidget):
                 data_sample.download_data(2000, partial=True)
                 data = Table(data_sample)
 
-        if data is not None and not len(data):
+        if data is not None and np.all(np.isnan(data.X)):
             data = None
 
         if data is not None and sp.issparse(data.X):
