@@ -8,7 +8,7 @@ from AnyQt.QtCore import Qt, QSize
 from AnyQt.QtGui import QColor, QPen, QBrush
 from AnyQt.QtWidgets import QGraphicsScene, QGraphicsLineItem, QSizePolicy
 
-from Orange.data import Table, filter, Variable
+from Orange.data import Table, filter as data_filter, Variable
 from Orange.data.sql.table import SqlTable, LARGE_TABLE, DEFAULT_SAMPLE_TIME
 from Orange.preprocess import Discretize
 from Orange.preprocess.discretize import EqualFreq
@@ -24,7 +24,8 @@ from Orange.widgets.visualize.utils.vizrank import VizRankDialogAttrPair, \
     VizRankMixin
 from Orange.widgets.visualize.utils import (
     CanvasText, CanvasRectangle, ViewWithPress)
-from Orange.widgets.widget import OWWidget, AttributeList, Input, Output
+from Orange.widgets.widget import OWWidget, AttributeList, Input, Output, \
+    Msg
 
 
 class ChiSqStats:
@@ -54,7 +55,6 @@ class ChiSqStats:
         self.p = chi2.sf(
             self.chisq, (len(self.probs_x) - 1) * (len(self.probs_y) - 1))
 
-
 class SieveRank(VizRankDialogAttrPair):
     sort_names_in_row = True
 
@@ -84,6 +84,9 @@ class OWSieveDiagram(OWWidget, VizRankMixin(SieveRank)):
 
     graph_name = "canvas"  # QGraphicsScene
 
+    class Warning(OWWidget.Warning):
+        cochran = Msg("Data does not meet the Cochran's rule\n{}")
+
     want_control_area = False
 
     settings_version = 1
@@ -270,7 +273,7 @@ class OWSieveDiagram(OWWidget, VizRankMixin(SieveRank)):
                 "Features from the input signal are not present in the data")
             return
         old_attrs = self.attr_x, self.attr_y
-        self.attr_x, self.attr_y = [f for f in (features * 2)[:2]]
+        self.attr_x, self.attr_y = (features * 2)[:2]
         self.attr_box.setEnabled(False)
         if (self.attr_x, self.attr_y) != old_attrs:
             self.selection = set()
@@ -313,9 +316,9 @@ class OWSieveDiagram(OWWidget, VizRankMixin(SieveRank)):
                 width = 4
                 val_x, val_y = area.value_pair
                 filts.append(
-                    filter.Values([
-                        filter.FilterDiscrete(self.attr_x.name, [val_x]),
-                        filter.FilterDiscrete(self.attr_y.name, [val_y])
+                    data_filter.Values([
+                        data_filter.FilterDiscrete(self.attr_x.name, [val_x]),
+                        data_filter.FilterDiscrete(self.attr_y.name, [val_y])
                     ]))
             else:
                 width = 1
@@ -325,7 +328,7 @@ class OWSieveDiagram(OWWidget, VizRankMixin(SieveRank)):
         if len(filts) == 1:
             filts = filts[0]
         else:
-            filts = filter.Values(filts, conjunction=False)
+            filts = data_filter.Values(filts, conjunction=False)
         selection = filts(self.discrete_data)
         idset = set(selection.ids)
         sel_idx = [i for i, id in enumerate(self.data.ids) if id in idset]
@@ -439,7 +442,7 @@ class OWSieveDiagram(OWWidget, VizRankMixin(SieveRank)):
 
             return f"{xt}<br/>{yt}<hr/>{ct}"
 
-
+        self.Warning.cochran.clear()
         for item in self.canvas.items():
             self.canvas.removeItem(item)
         if self.data is None or len(self.data) == 0 or \
@@ -516,6 +519,28 @@ class OWSieveDiagram(OWWidget, VizRankMixin(SieveRank)):
                   0, bottom)
         # Assume similar height for both lines
         text("N = " + fmt(chi.n), 0, bottom - xl.boundingRect().height())
+        msg = self._check_cochran(chi)
+        if msg is not None:
+            self.Warning.cochran(msg)
+
+    @staticmethod
+    def _check_cochran(chi):
+        """
+        Check Cochran's rule.
+        Return None if it is met, otherwise a string describing the problem.
+        """
+        expected = np.asarray(chi.expected, dtype=float)
+        cells = expected.size
+        if cells == 0:
+            return "no cells in contingency table"
+        eps = 1e-12
+        num_lt1 = (expected < 1.0 - eps).sum()
+        num_lt5 = (expected < 5.0 - eps).sum()
+        if num_lt1 > 0:
+            return "some expected frequencies are below 1"
+        if num_lt5 > 0.2 * cells:
+            return "more than 20% of expected frequencies are below 5"
+        return None
 
     def get_widget_name_extension(self):
         if self.data is not None:
