@@ -139,7 +139,7 @@ class OWProjectionWidgetBase(OWWidget, openclass=True):
 
         needs_merging = attr.is_discrete \
                         and max_categories is not None \
-                        and len(attr.values) >= max_categories
+                        and len(attr.values) > max_categories
         if return_labels and not needs_merging:
             assert attr.is_discrete
             return attr.values
@@ -667,7 +667,7 @@ class OWAnchorProjectionWidget(OWDataProjectionWidget, openclass=True):
     graph = SettingProvider(OWGraphWithAnchors)
 
     class Outputs(OWDataProjectionWidget.Outputs):
-        components = Output("Components", Table)
+        components = Output("Components", Table, dynamic=False)
 
     class Error(OWDataProjectionWidget.Error):
         sparse_data = Msg("Sparse data is not supported")
